@@ -1,12 +1,12 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "kaolin-themes" "1.7.4"
+(define-package "kaolin-themes" "20251007.1241"
   "A set of eye pleasing themes."
   '((emacs      "25.1")
     (autothemer "0.2.2")
     (cl-lib     "0.6"))
   :url "https://github.com/ogdenwebb/emacs-kaolin-themes"
-  :commit "fc0337582f36167b74cbdc86a48471092c8f3262"
-  :revdesc "fc0337582f36"
+  :commit "a0570401fa08fb6f3843e574d28823a8e079e943"
+  :revdesc "a0570401fa08"
   :keywords '("dark" "light" "teal" "blue" "violet" "purple" "brown" "theme" "faces")
   :authors '(("Ogden Webb" . "ogdenwebb@gmail.com"))
   :maintainers '(("Ogden Webb" . "ogdenwebb@gmail.com")))
